@@ -6,16 +6,14 @@ from rubicon.objc.eventloop import EventLoopPolicy
 
 
 # Some coroutines with known behavior for testing purposes.
-@asyncio.coroutine
-def do_stuff(results, x):
+async def do_stuff(results, x):
     for i in range(0, x):
         results.append(i)
-        yield from asyncio.sleep(0.1)
+        await asyncio.sleep(0.1)
 
 
-@asyncio.coroutine
-def stop_loop(loop, delay):
-    yield from asyncio.sleep(delay)
+async def stop_loop(loop, delay):
+    await asyncio.sleep(delay)
     loop.stop()
 
 
@@ -111,7 +109,7 @@ class AsyncReaderWriterTests(unittest.TestCase):
         self.loop.close()
 
     def test_tcp_echo(self):
-        """A simple TCP Echo client/server works as expected"""
+        """A simple TCP Echo client/server works as expected."""
         # This tests that you can:
         # * create a TCP server
         # * create a TCP client
@@ -123,39 +121,37 @@ class AsyncReaderWriterTests(unittest.TestCase):
 
         server_messages = []
 
-        @asyncio.coroutine
-        def echo_server(reader, writer):
-            data = yield from reader.read(100)
+        async def echo_server(reader, writer):
+            data = await reader.read(100)
             message = data.decode()
             server_messages.append(message)
 
             writer.write(data)
-            yield from writer.drain()
+            await writer.drain()
 
             writer.close()
 
         self.server = self.loop.run_until_complete(
-            asyncio.start_server(echo_server, '127.0.0.1', 3742)
+            asyncio.start_server(echo_server, "127.0.0.1", 3742)
         )
 
         client_messages = []
 
-        @asyncio.coroutine
-        def echo_client(message):
-            reader, writer = yield from asyncio.open_connection('127.0.0.1', 3742)
+        async def echo_client(message):
+            reader, writer = await asyncio.open_connection("127.0.0.1", 3742)
 
             writer.write(message.encode())
 
-            data = yield from reader.read(100)
+            data = await reader.read(100)
             client_messages.append(data.decode())
 
             writer.close()
 
-        self.loop.run_until_complete(echo_client('Hello, World!'))
-        self.loop.run_until_complete(echo_client('Goodbye, World!'))
+        self.loop.run_until_complete(echo_client("Hello, World!"))
+        self.loop.run_until_complete(echo_client("Goodbye, World!"))
 
-        self.assertEqual(server_messages, ['Hello, World!', 'Goodbye, World!'])
-        self.assertEqual(client_messages, ['Hello, World!', 'Goodbye, World!'])
+        self.assertEqual(server_messages, ["Hello, World!", "Goodbye, World!"])
+        self.assertEqual(client_messages, ["Hello, World!", "Goodbye, World!"])
 
 
 class AsyncSubprocessTests(unittest.TestCase):
@@ -168,18 +164,17 @@ class AsyncSubprocessTests(unittest.TestCase):
         self.loop.close()
 
     def test_subprocess(self):
-        @asyncio.coroutine
-        def list_dir():
-            proc = yield from asyncio.create_subprocess_shell(
-                'ls',
+        async def list_dir():
+            proc = await asyncio.create_subprocess_shell(
+                "ls",
                 stdout=asyncio.subprocess.PIPE,
             )
 
             entries = set()
-            line = yield from proc.stdout.readline()
+            line = await proc.stdout.readline()
             while line:
-                entries.add(line.decode('utf-8').strip())
-                line = yield from proc.stdout.readline()
+                entries.add(line.decode("utf-8").strip())
+                line = await proc.stdout.readline()
 
             # Cleanup - close the transport.
             proc._transport.close()
@@ -192,6 +187,6 @@ class AsyncSubprocessTests(unittest.TestCase):
         # Everything in the sample set, less everything from the result,
         # should be an empty set.
         self.assertEqual(
-            {'README.rst', 'MANIFEST.in', 'setup.py', 'setup.cfg'} - task.result(),
-            set()
+            {"README.rst", "MANIFEST.in", "setup.py", "setup.cfg"} - task.result(),
+            set(),
         )
